@@ -14,14 +14,14 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[7])
+        sf = SimpleFormat(quarter_durations=[7])
         v = sf.to_stream_voice()
         v.add_to_score(self.score, 1, 1)
         result_path = path + '_test_1'
         self.score.write(path=result_path)
 
     def test_2(self):
-        sf = SimpleFormat(durations=[12.5])
+        sf = SimpleFormat(quarter_durations=[12.5])
         v = sf.to_stream_voice()
         v.add_to_score(self.score, 1, 1)
         result_path = path + '_test_2'
@@ -29,7 +29,7 @@ class Test(TestCase):
 
     def test_3(self):
         # sf = SimpleFormat(durations=[Fraction(4) + Fraction(1, 2), Fraction(1, 2)])
-        sf = SimpleFormat(durations=[Fraction(4, 1) + Fraction(5, 7), Fraction(5, 7)])
+        sf = SimpleFormat(quarter_durations=[Fraction(4, 1) + Fraction(5, 7), Fraction(5, 7)])
         # sf = SimpleFormat(durations=[Fraction(4, 1) + Fraction(5, 7), Fraction(2, 7)])
         v = sf.to_stream_voice()
         v.add_to_score(self.score, 1, 1)
