@@ -7,7 +7,7 @@ from musicscore.musictree.treeclef import BASS_CLEF, TREBLE_CLEF, ALTO_CLEF, TEN
 from musicscore.musictree.treescoretimewise import TreeScoreTimewise
 from tests.score_templates.xml_test_score import TestScore
 
-path = os.path.abspath(__file__).split('.')[0]
+path = str(os.path.abspath(__file__).split('.')[0])
 
 
 class Test(TestCase):
@@ -15,7 +15,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
+        sf = SimpleFormat(quarter_durations=[1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
         sf.chords[0].add_clef(BASS_CLEF)
         sf.chords[1].add_clef(TREBLE_CLEF)
         sf.chords[2].add_clef(PERCUSSION_CLEF)
