@@ -13,7 +13,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[4, 4, 4, 4, 4])
+        sf = SimpleFormat(quarter_durations=[4, 4, 4, 4, 4])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
         self.score.get_measure(3).add_page_break()
@@ -23,10 +23,10 @@ class Test(TestCase):
         TestScore().assert_template(result_path=result_path)
 
     def test_2(self):
-        sf = SimpleFormat(durations=[4, 4, 4, 4, 4])
+        sf = SimpleFormat(quarter_durations=[4, 4, 4, 4, 4])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
-        sf = SimpleFormat(durations=[4, 4, 4, 4, 4])
+        sf = SimpleFormat(quarter_durations=[4, 4, 4, 4, 4])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 2)
         self.score.get_measure(3).add_page_break()
