@@ -12,7 +12,7 @@ path = os.path.abspath(__file__).split('.')[0]
 class Test(TestCase):
     def setUp(self) -> None:
         self.score = TreeScoreTimewise()
-        sf = SimpleFormat(durations=30 * [4])
+        sf = SimpleFormat(quarter_durations=30 * [4])
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
 
