@@ -13,7 +13,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 1])
+        sf = SimpleFormat(quarter_durations=[1, 1])
         sf.chords[0].add_clef(BASS_CLEF)
         v = sf.to_stream_voice(1)
         v.add_to_score(self.score, 1, 1)
